% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/boundaries.R
\name{boundaries}
\alias{boundaries}
\title{Boundaries for group sequential designs}
\usage{
boundaries(
  timing,
  alpha,
  beta,
  side,
  futility = "none",
  es_alpha,
  es_beta = NULL,
  tol = 1e+09,
  type = "design",
  design_R = NULL
)
}
\arguments{
\item{timing}{Expected timings of interim analyses and final analysis.}

\item{alpha}{The level of type I error}

\item{beta}{The level of type II error}

\item{side}{Whether a 1- or 2-sided hypothesis test is used. Options are 1 or 2.}

\item{futility}{Futility boundaries added to design. Options are: none, non-binding and binding. Default is "none".}

\item{es_alpha}{The spending function for alpha-spending. Options are: "esOF" (Lan & DeMets version of O'Brien-Fleming), "esPoc" (Lan & DeMets version of Pocock), "HSDC" (Hwang Sihi and DeCani) and "rho" (rho family).}

\item{es_beta}{The spending function for beta-spending. For options see es_alpha.}

\item{tol}{Tolerance level.}

\item{type}{Whether the boundaries are used for design or analysis. Defaults to design.}

\item{design_R}{If type is analysis, a scalar for achieving the right amount of power must be provided.}
}
\value{
A \code{boundaries} object which includes:
\item{inf_frac}{Timing of interim analyses and final analysis. Potentially modified if \code{type = "analysis"}.}
\item{org_inf_frac}{Original timing. If \code{type = "design"} NULL.}
\item{alpha_ubound}{Upper alpha-spending boundaries}
\item{alpha_lbound}{Lower alpha-spending boundaries}
\item{alpha}{As input}
\item{alpha_spend}{List of cumulative and incremental spending}
\item{delta}{Drift parameter}
\item{design_R}{If \code{type = "analysis"} it is the scalar for correct power in the design. Else NULL.}
\item{info}{List of the information as the squareroot of the information increments and the squareroot of the cumulative information}
\item{beta_ubound}{Upper beta-spending boundaries}
\item{beta_lbound}{Lower beta-spending boundaries}
\item{root}{Scalar for achieving correct power}
\item{beta_spend}{List of cumulative and incremental spending}
\item{pwr}{List of probabilities for rejecting the null under the sample size settings being true at each analysis and the sum.}
\item{tIe}{List of probabilities for type-I-error at each analysis and the sum}
\item{side}{As input}
\item{beta}{As input}
\item{es_alpha}{As input}
\item{es_beta}{As input}
\item{type}{As input}
\item{futility}{As input}
}
\description{
Calculates alpha- and potentially beta-spending boundaries for group sequential 
designs for meta-analysis together with a scalar to achieve the wanted level of power.
}
\examples{
boundaries(timing = c(0.25, 0.5, 0.75, 1), alpha = 0.05, beta = 0.1,
 side = 2, futility = "non-binding", es_alpha = "esOF", es_beta = "esOF")

}
